@@ -25,33 +25,52 @@ import collections
 import hashlib
 import logging
 import shelve
-import six
 import ssl
 import sys
 import tempfile
 import time
 import xml.dom
+import html.entities
+from http.client import HTTPSConnection
+
+from . import version
 
-__version__ = "2.3.0"
 __author__ = "Amr Hassan, hugovk, Mice Pápai"
 __copyright__ = (
     "Copyright (C) 2008-2010 Amr Hassan, 2013-2018 hugovk, " "2017 Mice Pápai"
 )
 __license__ = "apache2"
 __email__ = "amr.hassan@gmail.com"
+__version__ = version.__version__
 
+if sys.version_info < (3,):
+    raise ImportError(
+        """pylast 3.0 and above are no longer compatible with Python 2.
 
-if sys.version_info.major == 2:
-    import htmlentitydefs
-    from httplib import HTTPSConnection
-    from urllib import quote_plus as url_quote_plus
+This is pylast {} and you are using Python {}.
+Make sure you have pip >= 9.0 and setuptools >= 24.2 and retry:
+
+ $ pip install --upgrade pip setuptools
+
+Other choices:
+
+- Upgrade to Python 3.
+
+- Install an older version of pylast:
+
+$ pip install 'pylast<3.0'
+
+For more information:
+
+https://github.com/pylast/pylast/issues/265
+""".format(
+            version, ".".join([str(v) for v in sys.version_info[:3]])
+        )
+    )
 else:
-    import html.entities as htmlentitydefs
-    from http.client import HTTPSConnection
+    # Keep importable on Python 2 for a while to show ImportError
     from urllib.parse import quote_plus as url_quote_plus
 
-    unichr = chr
-
 
 STATUS_INVALID_SERVICE = 2
 STATUS_INVALID_METHOD = 3
@@ -88,12 +107,11 @@ DOMAIN_RUSSIAN = 9
 DOMAIN_JAPANESE = 10
 DOMAIN_CHINESE = 11
 
-# COVER_X is deprecated since 2.1.0 and will be removed in a future version
-SIZE_SMALL = COVER_SMALL = 0
-SIZE_MEDIUM = COVER_MEDIUM = 1
-SIZE_LARGE = COVER_LARGE = 2
-SIZE_EXTRA_LARGE = COVER_EXTRA_LARGE = 3
-SIZE_MEGA = COVER_MEGA = 4
+SIZE_SMALL = 0
+SIZE_MEDIUM = 1
+SIZE_LARGE = 2
+SIZE_EXTRA_LARGE = 3
+SIZE_MEGA = 4
 
 IMAGES_ORDER_POPULARITY = "popularity"
 IMAGES_ORDER_DATE = "dateadded"
@@ -113,14 +131,14 @@ SCROBBLE_MODE_SKIPPED = "S"
 # Delay time in seconds from section 4.4 of https://www.last.fm/api/tos
 DELAY_TIME = 0.2
 
-# Python >3.4 and >2.7.9 has sane defaults
+# Python >3.4 has sane defaults
 SSL_CONTEXT = ssl.create_default_context()
 
 logger = logging.getLogger(__name__)
 logging.getLogger(__name__).addHandler(logging.NullHandler())
 
 
-class _Network(object):
+class _Network:
     """
     A music social network website such as Last.fm or
     one with a Last.fm-compatible API.
@@ -777,7 +795,7 @@ class LibreFMNetwork(_Network):
         )
 
 
-class _ShelfCacheBackend(object):
+class _ShelfCacheBackend:
     """Used as a backend for caching cacheable requests."""
 
     def __init__(self, file_path=None):
@@ -798,7 +816,7 @@ class _ShelfCacheBackend(object):
         self.shelf[key] = xml_string
 
 
-class _Request(object):
+class _Request:
     """Representing an abstract web service operation."""
 
     def __init__(self, network, method_name, params=None):
@@ -963,7 +981,7 @@ class _Request(object):
             raise WSError(self.network, status, details)
 
 
-class SessionKeyGenerator(object):
+class SessionKeyGenerator:
     """Methods of generating a session key:
     1) Web Authentication:
         a. network = get_*_network(API_KEY, API_SECRET)
@@ -1017,11 +1035,9 @@ class SessionKeyGenerator(object):
 
         token = self._get_web_auth_token()
 
-        url = "%(homepage)s/api/auth/?api_key=%(api)s&token=%(token)s" % {
-            "homepage": self.network.homepage,
-            "api": self.network.api_key,
-            "token": token,
-        }
+        url = "{homepage}/api/auth/?api_key={api}&token={token}".format(
+            homepage=self.network.homepage, api=self.network.api_key, token=token
+        )
 
         self.web_auth_tokens[url] = token
 
@@ -1088,7 +1104,7 @@ def _string_output(func):
     return r
 
 
-class _BaseObject(object):
+class _BaseObject:
     """An abstract webservices object."""
 
     network = None
@@ -1110,10 +1126,10 @@ class _BaseObject(object):
 
     def __hash__(self):
         # Convert any ints (or whatever) into strings
-        values = map(six.text_type, self._get_params().values())
+        values = map(str, self._get_params().values())
 
         return hash(self.network) + hash(
-            six.text_type(type(self))
+            str(type(self))
             + "".join(list(self._get_params().keys()) + list(values)).lower()
         )
 
@@ -1177,7 +1193,7 @@ class _BaseObject(object):
         return _extract(node, section)
 
 
-class _Chartable(object):
+class _Chartable:
     """Common functions for classes with charts."""
 
     def __init__(self, ws_prefix):
@@ -1248,7 +1264,7 @@ class _Chartable(object):
         return seq
 
 
-class _Taggable(object):
+class _Taggable:
     """Common functions for classes with tags."""
 
     def __init__(self, ws_prefix):
@@ -1577,7 +1593,7 @@ class Album(_Opus):
     __hash__ = _Opus.__hash__
 
     def __init__(self, artist, title, network, username=None, info=None):
-        super(Album, self).__init__(artist, title, network, "album", username, info)
+        super().__init__(artist, title, network, "album", username, info)
 
     def get_tracks(self):
         """Returns the list of Tracks on this album."""
@@ -1641,7 +1657,7 @@ class Artist(_BaseObject, _Taggable):
         return "pylast.Artist({}, {})".format(repr(self.get_name()), repr(self.network))
 
     def __unicode__(self):
-        return six.text_type(self.get_name())
+        return str(self.get_name())
 
     @_string_output
     def __str__(self):
@@ -2046,7 +2062,7 @@ class Track(_Opus):
     __hash__ = _Opus.__hash__
 
     def __init__(self, artist, title, network, username=None, info=None):
-        super(Track, self).__init__(artist, title, network, "track", username, info)
+        super().__init__(artist, title, network, "track", username, info)
 
     def get_correction(self):
         """Returns the corrected track name."""
@@ -2682,22 +2698,18 @@ def md5(text):
 
 
 def _unicode(text):
-    if isinstance(text, six.binary_type):
-        return six.text_type(text, "utf-8")
-    elif isinstance(text, six.text_type):
+    if isinstance(text, bytes):
+        return str(text, "utf-8")
+    elif isinstance(text, str):
         return text
     else:
-        return six.text_type(text)
+        return str(text)
 
 
 def _string(string):
-    """For Python2 routines that can only process str type."""
     if isinstance(string, str):
         return string
-    casted = six.text_type(string)
-    if sys.version_info.major == 2:
-        casted = casted.encode("utf-8")
-    return casted
+    return str(string)
 
 
 def cleanup_nodes(doc):
@@ -2856,9 +2868,9 @@ def _unescape_htmlentity(string):
 
     # string = _unicode(string)
 
-    mapping = htmlentitydefs.name2codepoint
+    mapping = html.entities.name2codepoint
     for key in mapping:
-        string = string.replace("&%s;" % key, unichr(mapping[key]))
+        string = string.replace("&%s;" % key, chr(mapping[key]))
 
     return string
 
